==> distribution-5.58.0.zip: drr/regulation/fca/ukemir/refit/margin/validation/FCAUKEMIRMarginReportValidator.java <==
package drr.regulation.fca.ukemir.refit.margin.validation;

import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.fca.ukemir.refit.margin.CollateralReport;
import drr.regulation.fca.ukemir.refit.margin.FCAUKEMIRMarginReport;
import drr.regulation.fca.ukemir.refit.margin.PartiesToTheDerivative;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class FCAUKEMIRMarginReportValidator implements Validator<FCAUKEMIRMarginReport> {

	private List<ComparisonResult> getComparisonResults(FCAUKEMIRMarginReport o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("partiesToTheDerivative", (PartiesToTheDerivative) o.getPartiesToTheDerivative() != null ? 1 : 0, 1, 1), 
				checkCardinality("collateral", (CollateralReport) o.getCollateral() != null ? 1 : 0, 1, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, FCAUKEMIRMarginReport o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("FCAUKEMIRMarginReport", ValidationResult.ValidationType.CARDINALITY, "FCAUKEMIRMarginReport", path, "", res.getError());
				}
				return success("FCAUKEMIRMarginReport", ValidationResult.ValidationType.CARDINALITY, "FCAUKEMIRMarginReport", path, "");
			})
			.collect(toList());
	}

}

==> distribution-6.0.0-dev.128.zip: drr/regulation/fca/ukemir/refit/margin/validation/FCAUKEMIRMarginReportValidator.java <==
package drr.regulation.fca.ukemir.refit.margin.validation;

import com.google.common.collect.Lists;
import com.rosetta.model.lib.expression.ComparisonResult;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.Validator;
import drr.regulation.fca.ukemir.refit.margin.CollateralReport;
import drr.regulation.fca.ukemir.refit.margin.FCAUKEMIRMarginReport;
import drr.regulation.fca.ukemir.refit.margin.PartiesToTheDerivative;
import java.util.List;

import static com.google.common.base.Strings.isNullOrEmpty;
import static com.rosetta.model.lib.expression.ExpressionOperators.checkCardinality;
import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;
import static java.util.stream.Collectors.toList;

public class FCAUKEMIRMarginReportValidator implements Validator<FCAUKEMIRMarginReport> {

	private List<ComparisonResult> getComparisonResults(FCAUKEMIRMarginReport o) {
		return Lists.<ComparisonResult>newArrayList(
				checkCardinality("partiesToTheDerivative", (PartiesToTheDerivative) o.getPartiesToTheDerivative() != null ? 1 : 0, 1, 1), 
				checkCardinality("collateral", (CollateralReport) o.getCollateral() != null ? 1 : 0, 1, 1)
			);
	}

	@Override
	public List<ValidationResult<?>> getValidationResults(RosettaPath path, FCAUKEMIRMarginReport o) {
		return getComparisonResults(o)
			.stream()
			.map(res -> {
				if (!isNullOrEmpty(res.getError())) {
					return failure("FCAUKEMIRMarginReport", ValidationType.CARDINALITY, "FCAUKEMIRMarginReport", path, "", res.getError());
				}
				return success("FCAUKEMIRMarginReport", ValidationType.CARDINALITY, "FCAUKEMIRMarginReport", path, "");
			})
			.collect(toList());
	}

}
